@@ -208,6 +208,7 @@ utils::globalVariables(c("nParamMax","nComponentsAll","nComponentsNonSeasonal","
 #' \donttest{ves(Y,model="MNN",h=10,holdout=TRUE,occurrence="l")}
 #'
 #' @importFrom smooth sowhat
+#' @importFrom greybox measures
 #' @export
 ves <- function(data, model="PPP", lags=c(frequency(data)),
                 persistence=c("common","individual","dependent"),
@@ -279,8 +280,9 @@ ves <- function(data, model="PPP", lags=c(frequency(data)),
                               nComponentsNonSeasonal, nComponentsAll, lagsModelMax);
 
         # Check the bounds
+        # Edit KFP: change symmetric to FALSE
         if(bounds=="a"){
-            eigenValues <- eigen(elements$matF - elements$matG %*% elements$matW, only.values=TRUE, symmetric=TRUE)$values;
+            eigenValues <- eigen(elements$matF - elements$matG %*% elements$matW, only.values=TRUE, symmetric=FALSE)$values;
             if(max(abs(eigenValues)>(1 + 1E-50))){
                 return(max(abs(eigenValues))*1E+100);
             }
@@ -390,28 +392,57 @@ ves <- function(data, model="PPP", lags=c(frequency(data)),
         if(seasonalType=="i"){
             #### Individual seasonality ####
             ### Persistence matrix
+            # Edit KFP: change the parameter space, make all persistence to have mean-reverting behaviour
+            # by forcing the off-diagonals to be negative so that the MA coefficient would be positive
+            # potentially works for VES(ANN) only for now - dependent persistence matrix
             if(persistenceEstimate){
                 if(persistenceType=="c"){
                     persistenceLength <- nComponentsAll;
+                    if(bounds=="u"){
+                        BLower <- c(BLower,rep(0,persistenceLength));
+                        BUpper <- c(BUpper,rep(1,persistenceLength));
+                    }
+                    else{
+                        BLower <- c(BLower,rep(-5,persistenceLength));
+                        BUpper <- c(BUpper,rep(5,persistenceLength));
+                    }
                 }
                 else if(persistenceType=="i"){
                     persistenceLength <- nComponentsAll*nSeries;
+                    if(bounds=="u"){
+                        BLower <- c(BLower,rep(0,persistenceLength));
+                        BUpper <- c(BUpper,rep(1,persistenceLength));
+                    }
+                    else{
+                        BLower <- c(BLower,rep(-5,persistenceLength));
+                        BUpper <- c(BUpper,rep(5,persistenceLength));
+                    }
                 }
+                # Edited by KFP
                 else if(persistenceType=="d"){
                     persistenceLength <- nComponentsAll*nSeries^2;
+                    if(bounds=="u"){
+                        BLower <- c(BLower,rep(0,persistenceLength));
+                        BUpper <- c(BUpper,rep(1,persistenceLength));
+                    }
+                    else{
+                        BLower <- c(BLower,rep(-5,persistenceLength));
+                        BUpper <- c(BUpper,rep(5,persistenceLength));
+                    }
                 }
                 else if(persistenceType=="s"){
                     persistenceLength <- (nComponentsAll-1)*nSeries+1;
+                    if(bounds=="u"){
+                        BLower <- c(BLower,rep(0,persistenceLength));
+                        BUpper <- c(BUpper,rep(1,persistenceLength));
+                    }
+                    else{
+                        BLower <- c(BLower,rep(-5,persistenceLength));
+                        BUpper <- c(BUpper,rep(5,persistenceLength));
+                    }
                 }
-                B <- c(B,rep(0.1,persistenceLength));
-                if(bounds=="u"){
-                    BLower <- c(BLower,rep(0,persistenceLength));
-                    BUpper <- c(BUpper,rep(1,persistenceLength));
-                }
-                else{
-                    BLower <- c(BLower,rep(-5,persistenceLength));
-                    BUpper <- c(BUpper,rep(5,persistenceLength));
-                }
+                B <- c(B,rep(1/persistenceLength,persistenceLength));
+
                 BNames <- c(BNames,paste0("Persistence",c(1:persistenceLength)));
             }
 
@@ -1486,7 +1517,7 @@ ves <- function(data, model="PPP", lags=c(frequency(data)),
     }
 
     if(!is.matrix(yForecast)){
-        yForecast <- as.matrix(yForecast,h,nSeries);
+        yForecast <- as.matrix(yForecast,nSeries,h);
     }
     if(any(yClasses=="ts")){
         yFitted <- ts(t(yFitted), start=yStart, frequency=yFrequency);
@@ -1514,10 +1545,10 @@ ves <- function(data, model="PPP", lags=c(frequency(data)),
     ##### Now let's deal with the holdout #####
     if(holdout){
         if(any(yClasses=="ts")){
-            yHoldout <- ts(data[(obsInSample+1):obsAll,], start=yForecastStart, frequency=yFrequency);
+            yHoldout <- ts(data[(obsInSample+1):obsAll,,drop=FALSE], start=yForecastStart, frequency=yFrequency);
         }
         else{
-            yHoldout <- zoo(data[(obsInSample+1):obsAll,], order.by=yForecastIndex);
+            yHoldout <- zoo(data[(obsInSample+1):obsAll,,drop=FALSE], order.by=yForecastIndex);
         }
         colnames(yHoldout) <- dataNames;
 
