@@ -1,7 +1,7 @@
 utils::globalVariables(c("obsInSample","componentsCommonLevel","componentsCommonSeasonal","componentsCommonTrend",
                          "initialValue","initialsCommonLevel","initialsCommonSeasonal","initialsCommonTrend",
                          "modelIsTrendy","nComponentsLevel","nComponentsSeasonal","nComponentsTrend",
-                         "nInitialsLevel","nInitialsSeasonal","nInitialsTrend",
+                         "nInitialsLevel","nInitialsSeasonal","nInitialsTrend","shortSample",
                          "nParametersDamped","nParametersLevel","nParametersSeasonal","nParametersTrend",
                          "parametersCommonDamped","parametersCommonLevel","parametersCommonSeasonal","parametersCommonTrend",
                          "allowMultiplicative","modelDo","ICsAll","cfObjective","lossFunction",
@@ -512,16 +512,28 @@ vets <- function(data, model="PPP", lags=c(frequency(data)),
         initialValue <- c(initialValueNew01, initialValueNew02);
 
         if(modelIsSeasonal){
-            # Matrix of linear trend and dummies for seasons
-            XValues <- rbind(rep(1,obsInSample),c(1:obsInSample),
-                             matrix(rep(diag(lagsModelMax)[-1,],ceiling(obsInSample/lagsModelMax)), lagsModelMax-1)[,1:obsInSample]);
+            if(modelIsTrendy && !shortSample){
+                # Matrix of linear trend and dummies for seasons
+                XValues <- rbind(rep(1,obsInSample),c(1:obsInSample),
+                                 matrix(rep(diag(lagsModelMax)[-1,],ceiling(obsInSample/lagsModelMax)),
+                                        lagsModelMax-1)[,1:obsInSample]);
+                initialSeasonValue <- (switch(Etype, "M"=log(yInSample), yInSample) %*%
+                                           t(XValues) %*% solve(XValues %*% t(XValues)))[,-2];
+            }
+            else{
+                # Matrix of dummies for seasons
+                XValues <- rbind(rep(1,obsInSample),
+                                 matrix(rep(diag(lagsModelMax)[-1,],ceiling(obsInSample/lagsModelMax)),
+                                        lagsModelMax-1)[,1:obsInSample]);
+                initialSeasonValue <- (switch(Etype, "M"=log(yInSample), yInSample) %*%
+                                           t(XValues) %*% solve(XValues %*% t(XValues)));
+            }
+
             # XValues <- rbind(c(1:obsInSample),
                              # matrix(rep(diag(lagsModelMax),ceiling(obsInSample/lagsModelMax)), lagsModelMax)[,1:obsInSample]);
             # initialSeasonValue <- ((switch(Etype, "M"=log(yInSample), yInSample)-
             #                             rowMeans(switch(Etype, "M"=log(yInSample), yInSample))) %*%
             #                             t(XValues) %*% solve(XValues %*% t(XValues)))[,-1];
-            initialSeasonValue <- (switch(Etype, "M"=log(yInSample), yInSample) %*%
-                                       t(XValues) %*% solve(XValues %*% t(XValues)))[,-2];
             initialSeasonValue[,-1] <- initialSeasonValue[,-1] + initialSeasonValue[,1];
             # Renormalise initials
             initialSeasonValue[] <- initialSeasonValue - rowMeans(initialSeasonValue);
@@ -544,14 +556,14 @@ vets <- function(data, model="PPP", lags=c(frequency(data)),
             statesNames <- "level";
         }
         else{
-            statesNames <- rep("level",nSeries);
+            statesNames <- paste0(rep("level",nSeries),"_",dataNames);
         }
         if(modelIsTrendy){
             if(componentsCommonTrend){
                 statesNames <- c(statesNames,"trend");
             }
             else{
-                statesNames <- c(statesNames,rep("trend",nSeries));
+                statesNames <- c(statesNames,paste0(rep("trend",nSeries),"_",dataNames));
             }
         }
         if(modelIsSeasonal){
@@ -559,11 +571,10 @@ vets <- function(data, model="PPP", lags=c(frequency(data)),
                 statesNames <- c(statesNames,"seasonal");
             }
             else{
-                statesNames <- c(statesNames,rep("seasonal",nSeries));
+                statesNames <- c(statesNames,paste0(rep("seasonal",nSeries),"_",dataNames));
             }
         }
         # Give proper names to all matrices
-        statesNames <- paste0(statesNames,"_",dataNames);
         rownames(matVt) <- statesNames;
         rownames(matF) <- colnames(matF) <- statesNames;
         colnames(matW) <- rownames(matG) <- statesNames;
@@ -1302,10 +1313,10 @@ vets <- function(data, model="PPP", lags=c(frequency(data)),
     ##### Now let's deal with the holdout #####
     if(holdout){
         if(any(yClasses=="ts")){
-            yHoldout <- ts(data[(obsInSample+1):obsAll,], start=yForecastStart, frequency=yFrequency);
+            yHoldout <- ts(data[(obsInSample+1):obsAll,,drop=FALSE], start=yForecastStart, frequency=yFrequency);
         }
         else{
-            yHoldout <- zoo(data[(obsInSample+1):obsAll,], order.by=yForecastIndex);
+            yHoldout <- zoo(data[(obsInSample+1):obsAll,,drop=FALSE], order.by=yForecastIndex);
         }
         colnames(yHoldout) <- dataNames;
 
